@@ -184,7 +184,7 @@ TukeyC.lmerMod <- function(x,
                                            effect = which,
                                            level = 1 - sig.level))
 
-  aux_mt1 <- aux_mt$coef[,1]
+  aux_mt1 <- with(aux_mt,estimate)
 
   aux_mt2 <- data.frame(means = aux_mt1,
                         reps = reps)
